<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>CustomCommandOptDlg</name>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="112"/>
        <source>Name:</source>
        <translation>नाम :</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="114"/>
        <source>Command:</source>
        <translation>कमांड :</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="116"/>
        <source>Shortcuts:</source>
        <translation>शॉर्टकट :</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="127"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="128"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="205"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="211"/>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="154"/>
        <source>Add Command</source>
        <translation>कमांड जोड़ें</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="160"/>
        <source>Edit Command</source>
        <translation>कमांड संपादन</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="170"/>
        <source>Delete Command</source>
        <translation>कमांड हटाएँ</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="191"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="193"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>जोड़ें</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="195"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>संचित करें</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="372"/>
        <source>Please enter a name</source>
        <translation>कृपया नाम दर्ज करें</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="386"/>
        <source>Please enter a command</source>
        <translation>कृपया कमांड दर्ज करें</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="436"/>
        <source>The name already exists,</source>
        <translation>नाम पहले से प्रयुक्त है,</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="437"/>
        <source>please input another one.</source>
        <translation>कृपया अन्य दर्ज करें।</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="618"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>ठीक है</translation>
    </message>
</context>
<context>
    <name>CustomCommandPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="212"/>
        <source>Add Command</source>
        <translation>कमांड जोड़ें</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="216"/>
        <source>No commands yet</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CustomCommandPlugin</name>
    <message>
        <location filename="../src/customcommand/customcommandplugin.cpp" line="50"/>
        <source>Custom commands</source>
        <translation>अनुकूलित कमांड</translation>
    </message>
</context>
<context>
    <name>CustomCommandSearchRstPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandsearchrstpanel.cpp" line="146"/>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
</context>
<context>
    <name>CustomThemeSettingDialog</name>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="236"/>
        <source>Custom Theme</source>
        <translation>अनुकूलित थीम</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="260"/>
        <source>Style:</source>
        <translation>शैली :</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="264"/>
        <source>Light</source>
        <translation>हल्का </translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="269"/>
        <source>Dark</source>
        <translation>गहरा</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="323"/>
        <source>Fore color:</source>
        <translation>फोरग्राउंड रंग :</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="330"/>
        <source>Back color:</source>
        <translation>बैकग्राउंड रंग :</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="348"/>
        <source>Prompt PS1:</source>
        <translation>सूचक PS1:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="352"/>
        <source>Prompt PS2:</source>
        <translation>सूचक PS2:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="423"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="431"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>पुष्टि करें</translation>
    </message>
</context>
<context>
    <name>ListView</name>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <source>Delete Server</source>
        <translation>सर्वर हटाएँ</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <location filename="../src/views/listview.cpp" line="492"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>क्या आप स्पष्ट होकर %1 को हटाना चाहते हैं ?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="269"/>
        <location filename="../src/main/mainwindow.cpp" line="324"/>
        <source>New window</source>
        <translation>नवीन विंडो</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="339"/>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="755"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="757"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>बंद करें</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1829"/>
        <source>Type path to download file</source>
        <translation>फाइल डाउनलोड हेतु पथ दर्ज करें</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="2135"/>
        <source>Custom Theme</source>
        <translation>अनुकूलित थीम</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/views/listview.cpp" line="304"/>
        <location filename="../src/views/listview.cpp" line="493"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="236"/>
        <location filename="../src/common/utils.cpp" line="244"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="305"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="494"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="241"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>पुष्टि करें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="514"/>
        <location filename="../src/settings/settings_translation.cpp" line="109"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close workspace</source>
        <translation>कार्यस्थल बंद करें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="517"/>
        <location filename="../src/settings/settings_translation.cpp" line="105"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close other workspaces</source>
        <translation>अन्य कार्यस्थल बंद करें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1177"/>
        <source>Could not find &quot;%1&quot;, starting &quot;%2&quot; instead. Please check your shell profile.</source>
        <translation>&quot;%1&quot; की प्राप्ति विफल होने के कारण उसके स्थान पर &quot;%2&quot; आरंभ होगा। कृपया अपना शैल प्रोफाइल देखें।</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1183"/>
        <source>Could not open &quot;%1&quot;, unable to run it</source>
        <translation>&quot;%1&quot; को खोलना विफल होने के कारण उसे निष्पादित करना संभव नहीं है</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1185"/>
        <source>Could not find &quot;%1&quot;, unable to run it</source>
        <translation>&quot;%1&quot; की प्राप्ति विफल होने के कारण उसे निष्पादित करना संभव नहीं है</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1215"/>
        <source>Output has been suspended by pressing Ctrl+S. Pressing Ctrl+Q to resume.</source>
        <translation>Ctrl+S कुंजी संयोजन दबाने के कारण आउटपुट स्थगित किया गया। पुनः जारी रखने हेतु Ctrl+Q दबाएँ।</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="132"/>
        <location filename="../src/settings/settings_translation.cpp" line="133"/>
        <source>Tab title format</source>
        <translation>टैब शीर्षक प्रारूप</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="134"/>
        <location filename="../src/settings/settings_translation.cpp" line="135"/>
        <source>Remote tab title format</source>
        <translation>दूरस्थ टैब शीर्षक प्रारूप</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamedlg.cpp" line="203"/>
        <location filename="../src/views/tabbar.cpp" line="504"/>
        <location filename="../src/settings/settings_translation.cpp" line="81"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Rename title</source>
        <translation>शीर्षक बदलें</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="498"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close tab</source>
        <translation>टैब बंद करें</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="501"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close other tabs</source>
        <translation>अन्य टैब बंद करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="33"/>
        <source>Copy on select</source>
        <translation>चयन होने पर कॉपी करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="35"/>
        <source>Cursor blink</source>
        <translation>निमिष कर्सर</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="37"/>
        <source>Cursor style</source>
        <translation>कर्सर शैली</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="39"/>
        <source>Scroll on keystroke</source>
        <translation>कुंजीपटल द्वारा स्क्रॉल</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="41"/>
        <source>Scroll on output</source>
        <translation>आउटपुट स्क्रॉल करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="43"/>
        <source>Hide Quake window after losing focus</source>
        <translation>उपयोक्ता द्वारा विंडो उपयोग न होने पर Quake विंडो अदृश्य करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="45"/>
        <location filename="../src/main/service.cpp" line="159"/>
        <source>Blur background</source>
        <translation>बैकग्राउंड हेतु धुंध प्रभाव</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="47"/>
        <source>Use on starting</source>
        <translation>आरंभ होने पर उपयोग करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="49"/>
        <source>Font</source>
        <translation>मुद्रलिपि</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="51"/>
        <source>Font size</source>
        <translation>मुद्रलिपि आकार</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="53"/>
        <location filename="../src/main/service.cpp" line="182"/>
        <source>Opacity</source>
        <translation>अपारदर्शिता</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="55"/>
        <source>Advanced</source>
        <translation>विस्तृत</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="57"/>
        <source>Cursor</source>
        <translation>कर्सर </translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="59"/>
        <source>Scroll</source>
        <translation>स्क्रॉल</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="61"/>
        <source>Window</source>
        <translation>विंडो</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="63"/>
        <source>Basic</source>
        <translation>सामान्य</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="65"/>
        <source>Interface</source>
        <translation>अंतरफलक</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="67"/>
        <source>Shortcuts</source>
        <translation>शॉर्टकट</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="69"/>
        <location filename="../src/main/mainwindow.cpp" line="1671"/>
        <source>Others</source>
        <translation>अन्य</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="71"/>
        <location filename="../src/main/terminalapplication.cpp" line="36"/>
        <location filename="../src/main/mainwindow.cpp" line="1669"/>
        <source>Terminal</source>
        <translation>टर्मिनल</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="73"/>
        <source>Workspace</source>
        <translation>कार्यस्थल</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="75"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Custom commands</source>
        <translation>अनुकूलित कमांड</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="77"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Display shortcuts</source>
        <translation>शॉर्टकट दिखाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="79"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Remote management</source>
        <translation>दूरस्थ प्रबंधन</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="83"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Fullscreen</source>
        <translation>पूर्ण स्क्रीन</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="85"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Copy</source>
        <translation>कॉपी करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="87"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Default size</source>
        <translation>डिफ़ॉल्ट आकार</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="89"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Paste</source>
        <translation>पेस्ट करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="91"/>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="93"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Select all</source>
        <translation>सभी चयनित करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="95"/>
        <source>Jump to next command</source>
        <translation>अगली कमांड पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="97"/>
        <source>Jump to previous command</source>
        <translation>पिछली कमांड पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="99"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom in</source>
        <translation>आकार बढ़ाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="101"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom out</source>
        <translation>आकार घटाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="103"/>
        <source>Close other windows</source>
        <translation>अन्य विंडो बंद करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="107"/>
        <source>Close window</source>
        <translation>विंडो बंद करें </translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="111"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Horizontal split</source>
        <translation>क्षैतिज विभाजन</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="113"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>New tab</source>
        <translation>नवीन टैब</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="115"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Next tab</source>
        <translation>अगला टैब</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="117"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Previous tab</source>
        <translation>पिछला टैब</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="119"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select left workspace</source>
        <translation>बायां कार्यस्थल चुनें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="121"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select lower workspace</source>
        <translation>निचला कार्यस्थल चुनें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="123"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select right workspace</source>
        <translation>दायां कार्यस्थल चुनें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="125"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select upper workspace</source>
        <translation>ऊपरी कार्यस्थल चुनें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="127"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Vertical split</source>
        <translation>लंबवत विभाजन</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="129"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Find</source>
        <translation>खोज</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="131"/>
        <source>Tab titles</source>
        <translation>टैब शीर्षक</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="137"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 1</source>
        <translation>टैब 1 पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="139"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 2</source>
        <translation>टैब 2 पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="141"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 3</source>
        <translation>टैब 3 पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="143"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 4</source>
        <translation>टैब 4 पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="145"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 5</source>
        <translation>टैब 5 पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="147"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 6</source>
        <translation>टैब 6 पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="149"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 7</source>
        <translation>टैब 7 पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="151"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 8</source>
        <translation>टैब 8 पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="153"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 9</source>
        <translation>टैब 9 पर जाएँ</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="155"/>
        <source>Disable flow control using Ctrl+S, Ctrl+Q</source>
        <translation>Ctrl+S, Ctrl+Q का उपयोग कर आउटपुट प्रवाह निष्क्रिय करें</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="157"/>
        <source>Shell profile</source>
        <translation>शैल प्रोफाइल</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="517"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="379"/>
        <source>The name should be no more than 32 characters</source>
        <translation>नाम में 32 से अधिक अक्षर नहीं होने चाहिए</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="583"/>
        <source>Select the private key file</source>
        <translation>निजी कुंजी की फाइल चुनें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="587"/>
        <location filename="../src/main/mainwindow.cpp" line="1851"/>
        <location filename="../src/common/utils.cpp" line="133"/>
        <source>Select</source>
        <translation>चुनें</translation>
    </message>
    <message>
        <location filename="../src/main/terminalapplication.cpp" line="39"/>
        <source>Terminal is an advanced terminal emulator with workspace, multiple windows, remote management, quake mode and other features.</source>
        <translation>टर्मिनल - कार्यस्थल, एकाधिक विंडो, दूरस्थ प्रबंधन, मोड व अन्य सुविधाओं युक्त एक सशक्त टर्मिनल अनुकरण प्रोग्राम है।</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1667"/>
        <source>Tabs</source>
        <translation>टैब</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1687"/>
        <source>Switch focus to &quot;+&quot; icon</source>
        <translation>&quot;+&quot; आइकन पर केंद्रित करें</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select tab</source>
        <translation>टैब चुनें</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1775"/>
        <location filename="../src/common/utils.cpp" line="148"/>
        <source>Select file to upload</source>
        <translation>अपलोड हेतु फाइल चुनें</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1782"/>
        <location filename="../src/common/utils.cpp" line="153"/>
        <source>Upload</source>
        <translation>अपलोड करें</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1845"/>
        <location filename="../src/common/utils.cpp" line="127"/>
        <source>Select a directory to save the file</source>
        <translation>फाइल संचय हेतु डायरेक्टरी चुनें</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="403"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="621"/>
        <location filename="../src/common/utils.cpp" line="254"/>
        <source>please set another one.</source>
        <translation>कृपया अन्य सेट करें।</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="173"/>
        <location filename="../src/common/utils.cpp" line="207"/>
        <source>Close this terminal?</source>
        <translation>यह टर्मिनल बंद करें?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="174"/>
        <location filename="../src/common/utils.cpp" line="208"/>
        <source>There is still a process running in this terminal. Closing the terminal will kill it.</source>
        <translation>इस टर्मिनल पर अभी एक प्रक्रिया कार्यरत है। टर्मिनल बंद करने से वह प्रक्रिया समाप्त हो जाएगी।</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="178"/>
        <location filename="../src/common/utils.cpp" line="212"/>
        <source>There are still %1 processes running in this terminal. Closing the terminal will kill all of them.</source>
        <translation>इस टर्मिनल पर अभी %1 प्रक्रियाएँ कार्यरत हैं। टर्मिनल बंद करने से वे सभी प्रक्रियाएँ समाप्त हो जाएँगी।</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="183"/>
        <location filename="../src/common/utils.cpp" line="203"/>
        <source>Close this window?</source>
        <translation>यह विंडो बंद करें?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="184"/>
        <location filename="../src/common/utils.cpp" line="204"/>
        <source>There are still processes running in this window. Closing the window will kill all of them.</source>
        <translation>इस विंडो पर अभी प्रक्रियाएँ कार्यरत हैं। विंडो बंद करने से वे सभी प्रक्रियाएँ समाप्त हो जाएँगी।</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Programs are still running in terminal</source>
        <translation>टर्मिनल में अभी भी प्रोग्राम कार्यरत हैं</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Are you sure you want to uninstall it?</source>
        <translation>क्या आप निश्चित ही इसे हटाना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="234"/>
        <location filename="../src/common/utils.cpp" line="238"/>
        <source>Are you sure you want to uninstall this application?</source>
        <translation>क्या आप निश्चित यह अनुप्रयोग हटाना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="235"/>
        <location filename="../src/common/utils.cpp" line="239"/>
        <source>You will not be able to use Terminal any longer.</source>
        <translation>अब आप टर्मिनल उपयोग नहीं कर सकेंगें।</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="245"/>
        <location filename="../src/common/utils.cpp" line="289"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>ठीक है</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="323"/>
        <source>Set the work directory</source>
        <translation>कार्य डायरेक्टरी सेट करें</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="326"/>
        <source>Set the window mode on starting</source>
        <translation>आरंभ होने पर विंडो मोड सेट करें</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="329"/>
        <source>Execute a command in the terminal</source>
        <translation>टर्मिनल में कमांड निष्पादित करें</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="332"/>
        <source>Run script string in the terminal</source>
        <translation>स्क्रिप्ट वाक्यांश टर्मिनल में निष्पादित करें</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="335"/>
        <source>Run in quake mode</source>
        <translation>Quake मोड में निष्पादित करें</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="338"/>
        <source>Keep terminal open when command finishes</source>
        <translation>कमांड पूर्ण होने तक टर्मिनल खुला रखें</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="201"/>
        <source>Add Server</source>
        <translation>सर्वर जोड़ें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="205"/>
        <source>No servers yet</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RemoteManagementPlugin</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="90"/>
        <source>Remote management</source>
        <translation>दूरस्थ प्रबंधन</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="216"/>
        <source>Make sure that rz and sz commands have been installed in the server before right clicking to upload and download files.</source>
        <translation>दाएँ क्लिक द्वारा फाइलें अपलोड व डाउनलोड करने से पहले सुनिश्चित करें कि rz एवं sz कमांड सर्वर पर इंस्टॉल हैं।</translation>
    </message>
</context>
<context>
    <name>RemoteManagementSearchPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementsearchpanel.cpp" line="225"/>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
</context>
<context>
    <name>ServerConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="70"/>
        <source>Advanced options</source>
        <translation>विस्तृत विकल्प</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="108"/>
        <source>Add Server</source>
        <translation>सर्वर जोड़ें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="144"/>
        <source>Server name:</source>
        <translation>सर्वर नाम :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="146"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="156"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="184"/>
        <source>Required</source>
        <translation>आवश्यक</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="154"/>
        <source>Address:</source>
        <translation>पता :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="161"/>
        <source>Port:</source>
        <translation>पोर्ट :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="182"/>
        <source>Username:</source>
        <translation>उपयोक्ता नाम :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="189"/>
        <source>Password:</source>
        <translation>कूटशब्द :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="195"/>
        <source>Certificate:</source>
        <translation>प्रमाणपत्र :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="211"/>
        <source>Group:</source>
        <translation>समूह :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="217"/>
        <source>Path:</source>
        <translation>पथ :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="223"/>
        <source>Command:</source>
        <translation>कमांड :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="229"/>
        <source>Encoding:</source>
        <translation>एन्कोडिंग :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="235"/>
        <source>Backspace key:</source>
        <translation>बैकस्पेस कुंजी :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="241"/>
        <source>Delete key:</source>
        <translation>कुंजी हटाएँ :</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="247"/>
        <source>Delete server</source>
        <translation>सर्वर डिलीट करें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="261"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="262"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>जोड़ें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="266"/>
        <source>Edit Server</source>
        <translation>सर्वर संपादन</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="267"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>संचित करें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="511"/>
        <source>Please enter a server name</source>
        <translation>कृपया सर्वर नाम दर्ज करें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="524"/>
        <source>Please enter an IP address</source>
        <translation>कृपया आईपी पता दर्ज करें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="529"/>
        <source>Please enter a port</source>
        <translation>कृपया पोर्ट दर्ज करें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="535"/>
        <source>Please enter a username</source>
        <translation>कृपया उपयोक्ता नाम दर्ज करें</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="549"/>
        <source>The server name already exists,</source>
        <translation>सर्वर नाम पहले से प्रयुक्त है,</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="550"/>
        <source>please input another one. </source>
        <translation>कृपया अन्य दर्ज करें।</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <location filename="../src/main/service.cpp" line="399"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>ठीक है</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Normal window</source>
        <translation>सामान्य विंडो</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Split screen</source>
        <translation>स्क्रीन विभाजन</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Maximum</source>
        <translation>अधिकतम</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Fullscreen</source>
        <translation>पूर्ण स्क्रीन</translation>
    </message>
</context>
<context>
    <name>ShortcutManager</name>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="283"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="292"/>
        <source>The shortcut %1 is invalid, </source>
        <translation>शॉर्टकट %1 अमान्य है,</translation>
    </message>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="299"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="306"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="312"/>
        <source>The shortcut %1 was already in use, </source>
        <translation>शॉर्टकट %1 पहले से प्रयुक्त है,</translation>
    </message>
</context>
<context>
    <name>TabRenameWidget</name>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="60"/>
        <source>Insert</source>
        <translation>प्रविष्ट करें</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>username: %u</source>
        <translation>उपयोक्ता नाम : %u</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>username@: %U</source>
        <translation>उपयोक्ता नाम @: %U</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>remote host: %h</source>
        <translation>दूरस्थ होस्ट : %h</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>session number: %#</source>
        <translation>सत्र संख्या : %#</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="110"/>
        <source>title set by shell: %w</source>
        <translation>शैल द्वारा सेट शीर्षक : %w</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>program name: %n</source>
        <translation>प्रोग्राम नाम : %n</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>current directory (short): %d</source>
        <translation>वर्तमान डायरेक्टरी (लघु): &amp;d</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>current directory (long): %D</source>
        <translation>वर्तमान डायरेक्टरी (दीर्घ): &amp;d</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>local host: %h</source>
        <translation>लोकल होस्ट : %h</translation>
    </message>
</context>
<context>
    <name>TermWidget</name>
    <message>
        <location filename="../src/views/termwidget.cpp" line="483"/>
        <source>Copy</source>
        <translation>कॉपी करें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="486"/>
        <source>Paste</source>
        <translation>पेस्ट करें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="495"/>
        <source>Open</source>
        <translation>खोलें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="499"/>
        <source>Open in file manager</source>
        <translation>फाइल प्रबंधक में खोलें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="508"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Horizontal split</source>
        <translation>क्षैतिज विभाजन</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="511"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Vertical split</source>
        <translation>लंबवत विभाजन</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="521"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>New tab</source>
        <translation>नवीन टैब</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="528"/>
        <source>Exit fullscreen</source>
        <translation>पूर्ण स्क्रीन बंद करें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="530"/>
        <source>Fullscreen</source>
        <translation>पूर्ण स्क्रीन</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="533"/>
        <source>Find</source>
        <translation>खोज</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="537"/>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="547"/>
        <source>Encoding</source>
        <translation>एन्कोडिंग</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Custom commands</source>
        <translation>अनुकूलित कमांड</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="551"/>
        <source>Remote management</source>
        <translation>दूरस्थ प्रबंधन</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="555"/>
        <source>Upload file</source>
        <translation>फाइल अपलोड करें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="556"/>
        <source>Download file</source>
        <translation>फाइल डाउनलोड करें</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="561"/>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="189"/>
        <location filename="../src/common/utils.cpp" line="223"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="191"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>बंद करें</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="224"/>
        <location filename="../src/common/utils.cpp" line="256"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>ठीक है</translation>
    </message>
</context>
</TS>